==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/sl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Souporaba v zveznem oblaku",
    "Invalid Federated Cloud ID" : "Neveljaven ID zveznega oblaka Nextcloud",
    "Sharing %s failed, because this item is already shared with %s" : "Nastavljanje souporabe %s je spodletelo, ker je ima uporabnik %s predmet že v souporabi.",
    "Not allowed to create a federated share with the same user" : "Ni dovoljeno ustvariti souporabe zveznega oblaka z istim uporabnikom",
    "File is already shared with %s" : "Datoteka je že v souporabi pri %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Omogočanje souporabe %s je spodletelo, ker ni mogoče najti %s. Najverjetneje je strežnik nedosegljiv.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Uporabnik %1$s vam je omogočil oddaljeno souporabo mape \"/%3$s\" (v imenu %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Uporabnik %1$s vam je omogočil oddaljeno souporabo mape \"/%3$s\"",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Omogoči souporabo prek #Nextcloud ID zveznega oblaka, več na %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Omogoči souporabo prek #Nextcloud ID zveznega oblaka",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "Open documentation" : "Odpri dokumentacijo",
    "Allow users on this server to send shares to other servers" : "Dovoli uporabnikom tega strežnika pošiljanje map za souporabo na druge strežnike.",
    "Allow users on this server to receive shares from other servers" : "Dovoli uporabnikom tega strežnika sprejemanje map za souporabo z drugih strežnikov.",
    "Federated Cloud" : "Zvezni oblak",
    "Your Federated Cloud ID:" : "Vaš ID zveznega oblaka:",
    "Share it:" : "Omogoči souporabo:",
    "Add to your website" : "Dodaj na spletišče",
    "Share with me via Nextcloud" : "Omogoči souporabo prek oblaka Nextcloud",
    "HTML Code:" : "Koda HTML:"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/sl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Souporaba v zveznem oblaku",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ali želite dodati oddaljeni delež {ime} od {lastnika}@{daljinsko}?",
    "Cancel" : "Prekliči",
    "Copy" : "Kopiraj",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje.",
    "Invalid Federated Cloud ID" : "Neveljaven ID zveznega oblaka Nextcloud",
    "Couldn't establish a federated share." : "Ni mogoče vzpostaviti zveznega mesta za souporabo.",
    "Not allowed to create a federated share with the same user" : "Ni dovoljeno ustvariti souporabe zveznega oblaka z istim uporabnikom",
    "File is already shared with %s" : "Datoteka je že v souporabi pri %s",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Omogoči souporabo prek #Nextcloud ID zveznega oblaka, več na %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Omogoči souporabo prek #Nextcloud ID zveznega oblaka",
    "Sharing" : "Souporaba",
    "Federated file sharing" : "Souporaba v zveznem oblaku",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "Open documentation" : "Odpri dokumentacijo",
    "Allow users on this server to send shares to other servers" : "Dovoli uporabnikom tega strežnika pošiljanje map za souporabo na druge strežnike.",
    "Allow users on this server to receive shares from other servers" : "Dovoli uporabnikom tega strežnika sprejemanje map za souporabo z drugih strežnikov.",
    "Federated Cloud" : "Zvezni oblak",
    "Your Federated Cloud ID:" : "Vaš ID zveznega oblaka:",
    "Add to your website" : "Dodaj na spletišče",
    "Share with me via Nextcloud" : "Omogoči souporabo prek oblaka Nextcloud",
    "HTML Code:" : "Koda HTML:",
    "Sharing %s failed, because this item is already shared with %s" : "Nastavljanje souporabe %s je spodletelo, ker je ima uporabnik %s predmet že v souporabi."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
